#   Finance::YahooUKQuote --- fetches quotes for European stocks 
#
#   Copyright (C) 1999 Dirk Eddelbuettel <edd@debian.org>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#   This modules is an adapted copy of the Finance::YahooQuote module by 
#   Dj Padzensky <djpadz@padz.net> which can be found at 
#	http://www.padz.net/~djpadz/YahooQuote/

package Finance::YahooUKQuote;
require 5.000;

require Exporter;
use strict;
use vars qw($VERSION @EXPORT @ISA $BASEURL);

use LWP::UserAgent;
use HTTP::Request::Common;

$VERSION = '0.01';
$BASEURL = "http://finance.uk.yahoo.com/quote.csv?d=s&s=" ;

@ISA = qw(Exporter);
@EXPORT = qw(&getukquote &getoneukquote);

sub getukquote {
    my @symbols = @_;
    my($x,@q,@qr,$ua,$url);
    $x = $";
    $" = "+";
    $url = $BASEURL."@symbols";
    $" = $x;
    $ua = LWP::UserAgent->new;
    $ua->env_proxy();
    foreach (split('\n',$ua->request(GET $url)->content)) {
        next if m/^\"SYMBOL\",\"PRICE\"/;
	next if m/index.html/;	# try BT.A.L in csv mode trigger this at YahooUK
	@q = grep { s/^"?(.*?)\s*"?\s*$/$1/; } split(',');
	push(@qr,[@q]);
    }
    return wantarray() ? @qr : \@qr;
}

# Input: A single stock symbol
# Output: An array, containing the list elements mentioned above.

sub getoneukquote {
    my @x;
    @x = &getquote($_[0]);
    return @{$x[0]} if defined @x;
}

__END__

1;

=head1 NAME

Finance::YahooUKQuote - Get a stock quote from Yahoo!

=head1 SYNOPSIS

  use Finance::YahooUKQuote;
  @quote = getoneukquote $symbol;	# Get a quote for a single symbol
  @quotes = getukquote @symbols;	# Get quotes for a bunch of symbols

=head1 DESCRIPTION

This module gets stock quotes from the UK site of Yahoo! Finance.  The
B<getoneukquote> function will return a quote for a single stock symbol,
while the B<getukquote> function will return a quote for each of the
stock symbols passed to it.  The return value of B<getoneukquote> is an
array, with the following elements:

    0 Symbol
    1 Last Price
    2 Trade Time
    3 Change
    4 Low
    5 High
    6 Previous Close
    7 Volume

Yes, Open is missing. Yahoo! UK just doesn't supply it.

The B<getquote> function returns an array of pointers to arrays with
the above structure.

=head1 COPYRIGHT

Copyright 1999 Dirk Eddelbuettel

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

The information that you obtain with this library may be copyrighted
by Yahoo! Inc., and is governed by their usage license.  See
http://www.yahoo.com/docs/info/gen_disclaimer.html for more information.

=head1 AUTHOR

Dirk Eddelbuettel <edd@debian.org>   

Updates to this modules might be found at
http://rosebud.sps.queensu.ca/~edd/code/yahooukquote/.

A lot of credit is due to Dj Padzensky for his FinanceQuote.pm module 
after which this is modelled. Dj Padzensky's Finance::YahooQuote home 
page can be found at http://www.padz.net/~djpadz/YahooQuote/

=cut
